﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Net;
using System.Net.Sockets;
using System.Threading;
using System.IO;

namespace WinNetworkIOCS
{
    public partial class Form1 : Form
    {
        enum APIcommands
        {
            MOVE = 0,
            PLAYFILE = 1,
            PLAYPHRASE = 2,
            STOP = 3
        };
        // Receiving byte array  
        byte[] bytes = new byte[1024];

        string ServerName = string.Empty;
        int Port = 0;
        Socket ClientSocket = null;
        IPEndPoint ServerEndPoint = null;
        NetworkStream ClientNetworkStream = null;
        StreamWriter ClientNetworkStreamWriter = null;
        bool isConnected = false;
        String theMessageToReceive;

        public Form1()
        {
            InitializeComponent();
        }

        protected void Form1_Load(object sender, EventArgs e)
        {
        }

        private void ConnectButton_Click(object sender, EventArgs e)
        {
            DisableFields();
            DoNetworkingConnection();
        }

        private void DisableFields()
        {
            PortBox.Enabled = false;
            IPAddressBox.Enabled = false;
            SendMessageBox.Enabled = false;
            ConnectButton.Enabled = false;
        }

        private void EnableFields()
        {
            PortBox.Enabled = true;
            IPAddressBox.Enabled = true;
            SendMessageBox.Enabled = true;
            ConnectButton.Enabled = true;
        }

        private void WriteToStatusBar(string Message)
        {
            EnableFields();
            StatusBar.Text = Message;
        }

        private void DoNetworkingConnection()
        {
            //Thread MyThread = null;

            try
            {
                ConnectTo();    // Aaron Added this, removing thread operations
            }
            catch (Exception e)
            {
                WriteToStatusBar("Failed to create thread with error: " + e.Message);
                return;
            }

        }

        private void ConnectTo()
        {
            ServerName = this.IPAddressBox.Text;
            Port = System.Convert.ToInt32(this.PortBox.Text);

            WriteToStatusBar("IP Address: " + ServerName + "Port: " + Port);
            // Socket ClientSocket = null;  // Moved to class scope - Aaron

            try
            {
                // Let's connect to a listening server
                try
                {
                    ClientSocket = new Socket(AddressFamily.InterNetwork, SocketType.Stream, ProtocolType.IP);
                    WriteToStatusBar("Socket is OK...");
                    isConnected = true;
                }
                catch (Exception e)
                {
                    isConnected = false;
                    throw new Exception("Failed to create client Socket: " + e.Message);
                }

                ServerEndPoint = new IPEndPoint(IPAddress.Parse(ServerName), Convert.ToInt16(Port));

                try
                {
                    ClientSocket.Connect(ServerEndPoint);
                    WriteToStatusBar("Connect() is OK...");
                }
                catch (Exception e)
                {
                    throw new Exception("Failed to connect client Socket: " + e.Message);
                }
            }
            catch (Exception e)
            {
                WriteToStatusBar(e.Message);
                ClientSocket.Close();
                return;
            }

            ClientNetworkStream = new NetworkStream(ClientSocket, true);

            ClientNetworkStreamWriter = new StreamWriter(ClientNetworkStream);
            WriteToStatusBar("Setting up StreamWriter...");

        }

        private void SendCommandButton_Click(object sender, EventArgs e)
        {

            if (!isConnected)
            {
                MessageBox.Show("Software Not Connecte to ER1", "Software Not Connected to ER1", MessageBoxButtons.OK);
                return;
            }
            ClientNetworkStreamWriter.AutoFlush = true;  // Flush(); // Added in front of following line
            ClientNetworkStreamWriter.Write(this.SendMessageBox.Text + "\n");  // Added \n\r removed .ToString()

            WriteToStatusBar("We wrote " + this.SendMessageBox.Text.Length.ToString() + " character(s) to the server. This Text: " + this.SendMessageBox.Text);

            ReceiveDataFromServer();
        }

        private void ReceiveDataFromServer()
        {
            try
            {
                // Receives data from a bound Socket. 
                int bytesRec = ClientSocket.Receive(bytes);

                // Converts byte array to string 
                theMessageToReceive += Encoding.ASCII.GetString(bytes, 0, bytesRec);

                // Continues to read the data till data isn't available 
                while (ClientSocket.Available > 0)
                {
                    bytesRec = ClientSocket.Receive(bytes);
                    theMessageToReceive += Encoding.ASCII.GetString(bytes, 0, bytesRec);
                }

                ServerReplyTextbox.Text = "The server reply: " + theMessageToReceive;
                theMessageToReceive = string.Empty;

            }
            catch (Exception exc)
            {
                MessageBox.Show(exc.ToString());
            }

        }

        private void CopyToMsgToSendBoxButton_Click(object sender, EventArgs e)
        {
            APIcommands APIcmd;
            string cmdText = string.Empty;

            APIcmd = (APIcommands) MsgToSendComboBox.SelectedIndex;

            switch (APIcmd)
            {
                case APIcommands.MOVE:
                    cmdText = @"move " + UnitsTextBox.Text + " " + UnitTypeComboBox.Text.Trim();
                    break;
                case APIcommands.PLAYFILE:
                    cmdText = "play file \"" + UnitsTextBox.Text.Trim() + "\"";
                    break;
                case APIcommands.PLAYPHRASE:
                    cmdText = "play phrase \"" + UnitsTextBox.Text.Trim() + "\"";
                    break;
                case APIcommands.STOP:
                    cmdText = "stop";
                    break;
                default:
                    break;
            }
            // SendMessageBox.Text = APIcmd.ToString();
            SendMessageBox.Text = cmdText;
        }

        private void MsgToSendComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            APIcommands apiCmd = (APIcommands) MsgToSendComboBox.SelectedIndex;
            switch (apiCmd)
            {
                case APIcommands.PLAYFILE:
                    UnitTypeComboBox.SelectedIndex = -1;
                    break;

                case APIcommands.PLAYPHRASE:
                    UnitTypeComboBox.SelectedIndex = -1;
                    break;

                case APIcommands.STOP:
                    UnitTypeComboBox.SelectedIndex = -1;
                    break;

                default:
                    break;
            }

            //if (MsgToSendComboBox.ToString().Substring(0,4).ToUpper().Trim() == "PLAY")
            //{
            //    UnitTypeComboBox.SelectedIndex = 0;
            //}

            //if (MsgToSendComboBox.SelectedIndex == (int) APIcommands.STOP)
            //{
            //    UnitTypeComboBox.SelectedIndex = 0;
            //}
        }

        
    }
}




 